@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: StatisticsHandler.py 10159 2017-08-08 11:28:27Z David $
+# $Id: StatisticsHandler.py 10184 2017-08-14 09:22:31Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-08-08 19:28:27 +0800 (Tue, 08 Aug 2017) $
-# $Revision: 10159 $
+# $Date: 2017-08-14 17:22:31 +0800 (Mon, 14 Aug 2017) $
+# $Revision: 10184 $
 
 from datetime import timedelta, datetime
 
@@ -36,16 +36,50 @@ STATUS_DICT = dict(ContactMailingStatus.STATUS_CHOICES)
 STATUS_NAMES = STATUS_DICT.values()
 STATUS_CODE = STATUS_DICT.keys()
 
+from django.db import connection
+from django.conf import settings
+# check if strftime function is in current mysql
+dbName = settings.DATABASES['default']['NAME']
+setNewMysqlFunc = True
+
+if settings.DATABASE_ENGINE == 'mysql':
+    with connection.cursor() as cursor:
+        cursor.execute(
+            """
+                SELECT ROUTINE_NAME
+                FROM INFORMATION_SCHEMA.ROUTINES
+                WHERE ROUTINE_TYPE="FUNCTION"
+                AND ROUTINE_SCHEMA="%s";
+            """ % (dbName, )
+        )
+        row = cursor.fetchall()
+
+        for ele in row:
+            if "strftime" in ele:
+                setNewMysqlFunc = False
+        
+        if setNewMysqlFunc:
+            cursor.execute(
+                """
+                    CREATE FUNCTION strftime(format varchar(255), d date)
+                    RETURNS varchar(64)
+                    LANGUAGE SQL
+                    DETERMINISTIC
+                    COMMENT 'synonym for date_format'
+                    return date_format(d, format) ;
+                """
+        )
+
 def getDateRange(startDate, endDate):
     """
     Get range of dates.
     """
-    if isinstance(startDate, str):
+    if isinstance(startDate, str) or isinstance(startDate, unicode):
         if startDate != "NaN":
-            startDate = datetime.strptime(startDate, '%Y-%m-%d')
+            startDate = datetime.strptime(startDate, '%Y-%m-%d %H:%M:%S')
     if isinstance(endDate, str):
         if endDate != "NaN":
-            endDate = datetime.strptime(endDate, '%Y-%m-%d')
+            endDate = datetime.strptime(endDate, '%Y-%m-%d %H:%M:%S')
     
     deltaDays = endDate - startDate 
     daysAmount = deltaDays.days + 1
@@ -552,12 +586,14 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
             rates = []
             
             for i in info:
-                if i in ('unsubscribe', 'deliverie', 'error'):
-                    totalValue = subscriberCount
-                elif i == 'sentTest':
-                    totalValue = testSubscriberCount
-                else:
-                    totalValue = info['deliverie']        
+                totalValue = subscriberCount
+                # if i in ('unsubscribe', 'deliverie', 'error'):
+                #     totalValue = subscriberCount
+                # elif i == 'sentTest':
+                #     totalValue = testSubscriberCount
+                # else:
+                #     totalValue = subscriberCount
+                #     totalValue = info['deliverie']        
                 
                 if i == 'open':            
                     value = percentage(info['open'] + info['openOnSite'], 
@@ -589,11 +625,16 @@ def getStatisticsTotalData(reqestGetData, subscriberCount, testSubscriberCount,
     
     # -- get range date content start ------------------------------------------
     deltaDays = None
-    startDate = reqestGetData.get('startDate', None)    
-    # startDate = allDataDates.startDate.encode('ascii','ignore')
     
-    endDate = reqestGetData.get('endDate', None)
-    # endDate = allDataDates.endDate.encode('ascii','ignore')
+    startDate = reqestGetData.get('startDate', None)
+    if isinstance(startDate, str) or isinstance(startDate, unicode):
+        if startDate != "NaN":
+            startDate = datetime.strptime(startDate, '%Y/%m/%d') 
+
+    endDate = reqestGetData.get('endDate', None) 
+    if isinstance(endDate, str) or isinstance(endDate, unicode):
+        if endDate != "NaN":
+            endDate = datetime.strptime(endDate, '%Y/%m/%d') 
     
     period = reqestGetData.get('period', 'week')    
     if period == 'week':
